/*
 * Whether or not to compile debug routines for the interrupt handling
 * code (0: disable, 1: enable).  Enabling will make the code slower.
 * The debug level itself needs to be set in implementation.c
 */
#define ENABLE_DEBUG_CYSIGNALS 0
